import functools

from nose.tools import istest, nottest


class TestSetBuilder(object):
    def __init__(self):
        self._test_funcs = []
    
    @nottest
    def add_test(self, func):
        self._test_funcs.append(func)
        
    def create(self, name, run_test):
        @istest
        class Tests(object):
            pass
            
        for test_func in self._test_funcs:
            self._add_test_func(Tests, test_func, run_test)
        
        Tests.__name__ = name
        return Tests
        
    def _add_test_func(self, cls, test_func, run_test):
        @functools.wraps(test_func)
        @istest
        def test_method(self):
            return run_test(test_func)
        
        setattr(cls, test_func.__name__, test_method)




#!/usr/bin/env python

import os
from distutils.core import setup


setup(
    name='nose-test-sets',
    version='0.2.0',
    description='Create test sets to test different implementations of the same interface',
    author='Michael Williamson',
    url='http://github.com/mwilliamson/spur.py',
    py_modules=["nose_test_sets"],
    install_requires=["nose>=1.0.0,<2"],
)
